@@ -16,21 +16,21 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.59)
   {
     '+grammar' => 'swim',
     '+toprule' => 'document',
-    '+version' => '0.0.1',
+    '+version' => '0.0.2',
     'block_blank' => {
       '.ref' => 'line_blank'
     },
     'block_code' => {
-      '.rgx' => qr/\G\\\\\\/
+      '.rgx' => qr/\G\\{3}\r?\n((?:.*(?:\r?\n|\z))*?)\\{3}(?:\r?\n|\z)(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'block_comment' => {
-      '.rgx' => qr/\G\#\#\#\r?\n((?:.*\r?\n)*?)\#\#\#\r?\n(?:\ *\r?\n)?/
+      '.rgx' => qr/\G\#{3}\r?\n((?:.*(?:\r?\n|\z))*?)\#{3}(?:\r?\n|\z)(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'block_func' => {
       '.rgx' => qr/\G<<<\ *([\w\-]+)\ *(?:(.*?)\ *|\r?\n((?:.*\r?\n)*?))\>\>\>\r?\n/
     },
     'block_head' => {
-      '.rgx' => qr/\G(={1,4})\ +(?:(.+?)\ +=+\r?\n|(.+\r?\n(?:[^\s].*\r?\n)*[^\s].*?)\ +=+\r?\n|(.+\r?\n(?:[^\s].*\r?\n)*)(?=[\ \*=\#]|\r?\n|\z))(?:\ *\r?\n)?/
+      '.rgx' => qr/\G(={1,4})\ +(?:(.+?)\ +=+(?:\r?\n|\z)|(.+\r?\n(?:[^\s].*\r?\n)*[^\s].*?)\ +=+(?:\r?\n|\z)|(.+\r?\n(?:[^\s].*\r?\n)*)(?=[\ \*=\#]|(?:\r?\n|\z)))(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'block_list' => {
       '.any' => [
@@ -46,10 +46,10 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.59)
       ]
     },
     'block_list_bullet' => {
-      '.rgx' => qr/\G(\*\ .*\r?\n(?:\*\ .*\r?\n|(?:\ *\r?\n)|\ \ .*\r?\n)*(?:\ *\r?\n)?)/
+      '.rgx' => qr/\G(\*\ .*(?:\r?\n|\z)(?:\*\ .*(?:\r?\n|\z)|(?:\ +(?:\r?\n|\z)|\r?\n)|\ {2}.*(?:\r?\n|\z))*)/
     },
     'block_list_data' => {
-      '.rgx' => qr/\G(\-\ .*\r?\n(?:\-\ .*\r?\n|(?:\ *\r?\n)|\ \ .*\r?\n)*)/
+      '.rgx' => qr/\G(\-\ .*(?:\r?\n|\z)(?:\-\ .*(?:\r?\n|\z)|(?:\ +(?:\r?\n|\z)|\r?\n)|\ {2}.*(?:\r?\n|\z))*)/
     },
     'block_list_item' => {
       '+min' => 0,
@@ -84,22 +84,22 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.59)
       ]
     },
     'block_list_number' => {
-      '.rgx' => qr/\G(\+\ .*\r?\n(?:\+\ .*\r?\n|(?:\ *\r?\n)|\ \ .*\r?\n)*(?:\ *\r?\n)?)/
+      '.rgx' => qr/\G(\+\ .*(?:\r?\n|\z)(?:\+\ .*(?:\r?\n|\z)|(?:\ +(?:\r?\n|\z)|\r?\n)|\ {2}.*(?:\r?\n|\z))*)/
     },
     'block_meta' => {
-      '.rgx' => qr/\G\-{3}\r?\n([\s\S]*?\r?\n|)\.{3}\r?\n/
+      '.rgx' => qr/\G\-{3}\r?\n([\s\S]*?\r?\n|)\.{3}(?:\r?\n|\z)(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'block_para' => {
-      '.rgx' => qr/\G((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z))+)(?:\ *\r?\n)?/
+      '.rgx' => qr/\G((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z))+)(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'block_pref' => {
-      '.rgx' => qr/\G((?:(?:\ *\r?\n)*\ \ .*\r?\n)+)(?:\ *\r?\n)?/
+      '.rgx' => qr/\G((?:(?:\ +(?:\r?\n|\z)|\r?\n)*\ \ .*(?:\r?\n|\z))+)(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'block_rule' => {
-      '.rgx' => qr/\G\-{4}\r?\n(?:\ *\r?\n)?/
+      '.rgx' => qr/\G\-{4}(?:\r?\n|\z)(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'block_title' => {
-      '.rgx' => qr/\G((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z)))={3,}\r?\n(?:(?:\ *\r?\n)((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z)))(?=(?:\ *\r?\n)|\z))?(?:\ *\r?\n)?/
+      '.rgx' => qr/\G((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z)))={3,}\r?\n(?:(?:\ +(?:\r?\n|\z)|\r?\n)((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z)))(?=(?:\ +(?:\r?\n|\z)|\r?\n)))?(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'block_top' => {
       '.any' => [
@@ -145,17 +145,17 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.59)
       ]
     },
     'block_verse' => {
-      '.rgx' => qr/\G\.\r?\n((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z))+)(?:\ *\r?\n)?/
+      '.rgx' => qr/\G\.\r?\n((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z))+)(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'document' => {
       '+min' => 0,
       '.ref' => 'block_top'
     },
     'line_blank' => {
-      '.rgx' => qr/\G(?:\ *\r?\n)/
+      '.rgx' => qr/\G(?:\ +(?:\r?\n|\z)|\r?\n)/
     },
     'line_comment' => {
-      '.rgx' => qr/\G\#\ ?(.*)\r?\n(?:\ *\r?\n)?/
+      '.rgx' => qr/\G\#\ ?(.*?)(?:\r?\n|\z)(?:\ +(?:\r?\n|\z)|\r?\n)?/
     },
     'marker_bold' => {
       '.rgx' => qr/\G\*/
