@@ -50,7 +50,7 @@ sub render_para {
             ) {};
             while (
                 $out =~
-                    s{(L<[^>]*)\n(\S[^>]*)}
+                    s{([LC]<[^>]*)\n(\S[^>]*)}
                     {$1$2}g
             ) {};
         }
